@@ -185,7 +185,7 @@ void ModuleView::addModule( KCModuleInfo *module )
     // Provide information to the users
 
     if( module->service()->hasServiceType(QStringLiteral("SystemSettingsExternalApp")) ||  // Is it an external app?
-            module->service()->substituteUid() ) { // ...or does it require UID substituion?
+            module->service()->substituteUid() ) { // ...or does it require UID substitution?
         QWidget * externalWidget = new ExternalAppModule( this, module );
         moduleScroll->setWidget( externalWidget );
     } else { // It must be a normal module then
@@ -219,6 +219,10 @@ void ModuleView::updatePageIconHeader( KPageWidgetItem * page, bool light )
 
     page->setHeader( moduleInfo->comment() );
     page->setIcon( QIcon::fromTheme( moduleInfo->icon() ) );
+    //HACK: not much other ways to detect is a qml kcm
+    if ( moduleProxy && moduleProxy->realModule()->inherits("KCModuleQml") ) {
+        page->setHeaderVisible(false);
+    }
     if( light ) {
         return;
     }
